Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(490)

Unified Diff: chrome/browser/chrome_browser_main_linux.cc

Issue 12382005: Rename RemovableDeviceNotifications=>StorageMonitor (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/chrome_browser_main_linux.h ('k') | chrome/browser/chrome_browser_main_mac.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chrome_browser_main_linux.cc
diff --git a/chrome/browser/chrome_browser_main_linux.cc b/chrome/browser/chrome_browser_main_linux.cc
index d7d1c2cbf96a89da05760be962510a10970bb65f..4f5c48aac063ea4a09f522d1d080471bbf6609d7 100644
--- a/chrome/browser/chrome_browser_main_linux.cc
+++ b/chrome/browser/chrome_browser_main_linux.cc
@@ -10,7 +10,7 @@
#include "device/media_transfer_protocol/media_transfer_protocol_manager.h"
#if !defined(OS_CHROMEOS)
-#include "chrome/browser/storage_monitor/removable_device_notifications_linux.h"
+#include "chrome/browser/storage_monitor/storage_monitor_linux.h"
#include "content/public/browser/browser_thread.h"
#endif
@@ -133,9 +133,8 @@ void ChromeBrowserMainPartsLinux::PreProfileInit() {
#if !defined(OS_CHROMEOS)
const base::FilePath kDefaultMtabPath("/etc/mtab");
- removable_device_notifications_linux_ =
- new chrome::RemovableDeviceNotificationsLinux(kDefaultMtabPath);
- removable_device_notifications_linux_->Init();
+ storage_monitor_ = new chrome::StorageMonitorLinux(kDefaultMtabPath);
+ storage_monitor_->Init();
#endif
if (!CommandLine::ForCurrentProcess()->HasSwitch(switches::kTestType)) {
@@ -152,7 +151,7 @@ void ChromeBrowserMainPartsLinux::PreProfileInit() {
}
void ChromeBrowserMainPartsLinux::PostProfileInit() {
// TODO(gbillock): Make this owned by RemovableDeviceNotificationsLinux.
if (!CommandLine::ForCurrentProcess()->HasSwitch(switches::kTestType)) {
media_transfer_protocol_device_observer_.reset(
new chrome::MediaTransferProtocolDeviceObserverLinux());
@@ -168,7 +167,7 @@ void ChromeBrowserMainPartsLinux::PostMainMessageLoopRun() {
// Release it now. Otherwise the FILE thread would be gone when we try to
// release it in the dtor and Valgrind would report a leak on almost ever
// single browser_test.
- removable_device_notifications_linux_ = NULL;
+ storage_monitor_ = NULL;
#endif
media_transfer_protocol_device_observer_.reset();
« no previous file with comments | « chrome/browser/chrome_browser_main_linux.h ('k') | chrome/browser/chrome_browser_main_mac.h » ('j') | no next file with comments »
@@ -152,7 +151,7 @@ void ChromeBrowserMainPartsLinux::PreProfileInit() {
}
void ChromeBrowserMainPartsLinux::PostProfileInit() {
- // TODO(gbillock): Make this owned by RemovableDeviceNotificationsLinux.
+ // TODO(gbillock): Make this owned by StorageMonitorLinux.
if (!CommandLine::ForCurrentProcess()->HasSwitch(switches::kTestType)) {
media_transfer_protocol_device_observer_.reset(

Powered by Google App Engine
This is Rietveld 408576698